@@ -213,10 +213,12 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -235,7 +237,7 @@ class AddRouteOptions:
     def __init__(
         self,
         *,
-        router_type: aws_cdk.aws_ec2.RouterType,
+        router_type: _aws_cdk_aws_ec2_ceddda9d.RouterType,
         destination_cidr_block: typing.Optional[builtins.str] = None,
         destination_ipv6_cidr_block: typing.Optional[builtins.str] = None,
         enables_internet_connectivity: typing.Optional[builtins.bool] = None,
@@ -250,7 +252,15 @@ class AddRouteOptions:
         :param existing_vpc_peering_route_key: 
         :param router_id: 
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__77cff1a961dfe56849028f489d387bf7a42f4363289b43e3bab5a7a69aec3aa6)
+            check_type(argname="argument router_type", value=router_type, expected_type=type_hints["router_type"])
+            check_type(argname="argument destination_cidr_block", value=destination_cidr_block, expected_type=type_hints["destination_cidr_block"])
+            check_type(argname="argument destination_ipv6_cidr_block", value=destination_ipv6_cidr_block, expected_type=type_hints["destination_ipv6_cidr_block"])
+            check_type(argname="argument enables_internet_connectivity", value=enables_internet_connectivity, expected_type=type_hints["enables_internet_connectivity"])
+            check_type(argname="argument existing_vpc_peering_route_key", value=existing_vpc_peering_route_key, expected_type=type_hints["existing_vpc_peering_route_key"])
+            check_type(argname="argument router_id", value=router_id, expected_type=type_hints["router_id"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "router_type": router_type,
         }
         if destination_cidr_block is not None:
@@ -265,11 +275,11 @@ class AddRouteOptions:
             self._values["router_id"] = router_id
 
     @builtins.property
-    def router_type(self) -> aws_cdk.aws_ec2.RouterType:
+    def router_type(self) -> _aws_cdk_aws_ec2_ceddda9d.RouterType:
         '''What type of router to route this traffic to.'''
         result = self._values.get("router_type")
         assert result is not None, "Required property 'router_type' is missing"
-        return typing.cast(aws_cdk.aws_ec2.RouterType, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.RouterType, result)
 
     @builtins.property
     def destination_cidr_block(self) -> typing.Optional[builtins.str]:
@@ -325,42 +335,42 @@ class AddRouteOptions:
 
 @jsii.interface(jsii_type="@smallcase/cdk-vpc-module.ISubnetsProps")
 class ISubnetsProps(typing_extensions.Protocol):
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="availabilityZones")
     def availability_zones(self) -> typing.List[builtins.str]:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cidrBlock")
     def cidr_block(self) -> typing.List[builtins.str]:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetGroupName")
     def subnet_group_name(self) -> builtins.str:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetType")
-    def subnet_type(self) -> aws_cdk.aws_ec2.SubnetType:
+    def subnet_type(self) -> _aws_cdk_aws_ec2_ceddda9d.SubnetType:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="egressNetworkACL")
     def egress_network_acl(self) -> typing.Optional[typing.List["NetworkACL"]]:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ingressNetworkACL")
     def ingress_network_acl(self) -> typing.Optional[typing.List["NetworkACL"]]:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="routes")
     def routes(self) -> typing.Optional[typing.List[AddRouteOptions]]:
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         ...
@@ -369,42 +379,42 @@ class ISubnetsProps(typing_extensions.Protocol):
 class _ISubnetsPropsProxy:
     __jsii_type__: typing.ClassVar[str] = "@smallcase/cdk-vpc-module.ISubnetsProps"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="availabilityZones")
     def availability_zones(self) -> typing.List[builtins.str]:
         return typing.cast(typing.List[builtins.str], jsii.get(self, "availabilityZones"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cidrBlock")
     def cidr_block(self) -> typing.List[builtins.str]:
         return typing.cast(typing.List[builtins.str], jsii.get(self, "cidrBlock"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetGroupName")
     def subnet_group_name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "subnetGroupName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetType")
-    def subnet_type(self) -> aws_cdk.aws_ec2.SubnetType:
-        return typing.cast(aws_cdk.aws_ec2.SubnetType, jsii.get(self, "subnetType"))
+    def subnet_type(self) -> _aws_cdk_aws_ec2_ceddda9d.SubnetType:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.SubnetType, jsii.get(self, "subnetType"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="egressNetworkACL")
     def egress_network_acl(self) -> typing.Optional[typing.List["NetworkACL"]]:
         return typing.cast(typing.Optional[typing.List["NetworkACL"]], jsii.get(self, "egressNetworkACL"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ingressNetworkACL")
     def ingress_network_acl(self) -> typing.Optional[typing.List["NetworkACL"]]:
         return typing.cast(typing.Optional[typing.List["NetworkACL"]], jsii.get(self, "ingressNetworkACL"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="routes")
     def routes(self) -> typing.Optional[typing.List[AddRouteOptions]]:
         return typing.cast(typing.Optional[typing.List[AddRouteOptions]], jsii.get(self, "routes"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "tags"))
@@ -414,18 +424,18 @@ typing.cast(typing.Any, ISubnetsProps).__jsii_proxy_class__ = lambda : _ISubnets
 
 
 class Network(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@smallcase/cdk-vpc-module.Network",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         subnets: typing.Sequence[ISubnetsProps],
-        vpc: aws_cdk.aws_ec2.VpcProps,
-        peering_configs: typing.Optional[typing.Mapping[builtins.str, "PeeringConfig"]] = None,
+        vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+        peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union["PeeringConfig", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -434,6 +444,10 @@ class Network(
         :param vpc: 
         :param peering_configs: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__df3f88ed1cc891dbd636f210624927d010c33ac961e6f577806e2dd937c456be)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = VPCProps(subnets=subnets, vpc=vpc, peering_configs=peering_configs)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -442,51 +456,73 @@ class Network(
     def create_subnet(
         self,
         option: ISubnetsProps,
-        vpc: aws_cdk.aws_ec2.Vpc,
-    ) -> typing.List[aws_cdk.aws_ec2.Subnet]:
+        vpc: _aws_cdk_aws_ec2_ceddda9d.Vpc,
+    ) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.Subnet]:
         '''
         :param option: -
         :param vpc: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__92666cd41c2c14d24ac75176f78720cccdba04127eb90a149be6f2fe21660cf1)
+            check_type(argname="argument option", value=option, expected_type=type_hints["option"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         peering_connection_id = PeeringConnectionInternalType()
 
-        return typing.cast(typing.List[aws_cdk.aws_ec2.Subnet], jsii.invoke(self, "createSubnet", [option, vpc, peering_connection_id]))
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.Subnet], jsii.invoke(self, "createSubnet", [option, vpc, peering_connection_id]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="natProvider")
-    def nat_provider(self) -> aws_cdk.aws_ec2.NatProvider:
-        return typing.cast(aws_cdk.aws_ec2.NatProvider, jsii.get(self, "natProvider"))
+    def nat_provider(self) -> _aws_cdk_aws_ec2_ceddda9d.NatProvider:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.NatProvider, jsii.get(self, "natProvider"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.Vpc:
-        return typing.cast(aws_cdk.aws_ec2.Vpc, jsii.get(self, "vpc"))
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.Vpc:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.Vpc, jsii.get(self, "vpc"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="natSubnets")
-    def nat_subnets(self) -> typing.List[aws_cdk.aws_ec2.PublicSubnet]:
-        return typing.cast(typing.List[aws_cdk.aws_ec2.PublicSubnet], jsii.get(self, "natSubnets"))
+    def nat_subnets(self) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet]:
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet], jsii.get(self, "natSubnets"))
 
     @nat_subnets.setter
-    def nat_subnets(self, value: typing.List[aws_cdk.aws_ec2.PublicSubnet]) -> None:
+    def nat_subnets(
+        self,
+        value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f78b8adef4396361d5c72de5dc0fba4922e4d9a7322c65f75ff8504d4bd76871)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "natSubnets", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="pbSubnets")
-    def pb_subnets(self) -> typing.List[aws_cdk.aws_ec2.PublicSubnet]:
-        return typing.cast(typing.List[aws_cdk.aws_ec2.PublicSubnet], jsii.get(self, "pbSubnets"))
+    def pb_subnets(self) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet]:
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet], jsii.get(self, "pbSubnets"))
 
     @pb_subnets.setter
-    def pb_subnets(self, value: typing.List[aws_cdk.aws_ec2.PublicSubnet]) -> None:
+    def pb_subnets(
+        self,
+        value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b69712fe7b2bc40ff22d1946b13d47d502e7bdb75a27de5e82a782f5b1e5ad06)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pbSubnets", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="pvSubnets")
-    def pv_subnets(self) -> typing.List[aws_cdk.aws_ec2.PrivateSubnet]:
-        return typing.cast(typing.List[aws_cdk.aws_ec2.PrivateSubnet], jsii.get(self, "pvSubnets"))
+    def pv_subnets(self) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet]:
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet], jsii.get(self, "pvSubnets"))
 
     @pv_subnets.setter
-    def pv_subnets(self, value: typing.List[aws_cdk.aws_ec2.PrivateSubnet]) -> None:
+    def pv_subnets(
+        self,
+        value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b5bfb10a99897571241006d792ce84acf324e915d0d0d7a70310260bbf97506a)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "pvSubnets", value)
 
 
@@ -499,29 +535,33 @@ class NetworkACL:
     def __init__(
         self,
         *,
-        cidr: aws_cdk.aws_ec2.AclCidr,
-        traffic: aws_cdk.aws_ec2.AclTraffic,
+        cidr: _aws_cdk_aws_ec2_ceddda9d.AclCidr,
+        traffic: _aws_cdk_aws_ec2_ceddda9d.AclTraffic,
     ) -> None:
         '''
         :param cidr: 
         :param traffic: 
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5a1970396c779835fc4afcade9ad3fdc707402f18a94acc262cf9e711955157f)
+            check_type(argname="argument cidr", value=cidr, expected_type=type_hints["cidr"])
+            check_type(argname="argument traffic", value=traffic, expected_type=type_hints["traffic"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cidr": cidr,
             "traffic": traffic,
         }
 
     @builtins.property
-    def cidr(self) -> aws_cdk.aws_ec2.AclCidr:
+    def cidr(self) -> _aws_cdk_aws_ec2_ceddda9d.AclCidr:
         result = self._values.get("cidr")
         assert result is not None, "Required property 'cidr' is missing"
-        return typing.cast(aws_cdk.aws_ec2.AclCidr, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.AclCidr, result)
 
     @builtins.property
-    def traffic(self) -> aws_cdk.aws_ec2.AclTraffic:
+    def traffic(self) -> _aws_cdk_aws_ec2_ceddda9d.AclTraffic:
         result = self._values.get("traffic")
         assert result is not None, "Required property 'traffic' is missing"
-        return typing.cast(aws_cdk.aws_ec2.AclTraffic, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.AclTraffic, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -563,7 +603,14 @@ class PeeringConfig:
         :param peer_owner_id: 
         :param peer_region: 
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__906788234b850289efe7c3dfd41ad9a7598ad048a1820338c1962e640c00d246)
+            check_type(argname="argument peering_vpc_id", value=peering_vpc_id, expected_type=type_hints["peering_vpc_id"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument peer_assume_role_arn", value=peer_assume_role_arn, expected_type=type_hints["peer_assume_role_arn"])
+            check_type(argname="argument peer_owner_id", value=peer_owner_id, expected_type=type_hints["peer_owner_id"])
+            check_type(argname="argument peer_region", value=peer_region, expected_type=type_hints["peer_region"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "peering_vpc_id": peering_vpc_id,
             "tags": tags,
         }
@@ -620,7 +667,7 @@ class PeeringConfig:
 )
 class PeeringConnectionInternalType:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -648,8 +695,8 @@ class VPCProps:
         self,
         *,
         subnets: typing.Sequence[ISubnetsProps],
-        vpc: aws_cdk.aws_ec2.VpcProps,
-        peering_configs: typing.Optional[typing.Mapping[builtins.str, PeeringConfig]] = None,
+        vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+        peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param subnets: 
@@ -657,8 +704,13 @@ class VPCProps:
         :param peering_configs: 
         '''
         if isinstance(vpc, dict):
-            vpc = aws_cdk.aws_ec2.VpcProps(**vpc)
-        self._values: typing.Dict[str, typing.Any] = {
+            vpc = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc)
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__276e14ede93619c8496d33625e8b9426df9db19c536b76f6785db1fff0434a40)
+            check_type(argname="argument subnets", value=subnets, expected_type=type_hints["subnets"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument peering_configs", value=peering_configs, expected_type=type_hints["peering_configs"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "subnets": subnets,
             "vpc": vpc,
         }
@@ -672,10 +724,10 @@ class VPCProps:
         return typing.cast(typing.List[ISubnetsProps], result)
 
     @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.VpcProps:
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.VpcProps:
         result = self._values.get("vpc")
         assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.VpcProps, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.VpcProps, result)
 
     @builtins.property
     def peering_configs(
@@ -707,3 +759,79 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__77cff1a961dfe56849028f489d387bf7a42f4363289b43e3bab5a7a69aec3aa6(
+    *,
+    router_type: _aws_cdk_aws_ec2_ceddda9d.RouterType,
+    destination_cidr_block: typing.Optional[builtins.str] = None,
+    destination_ipv6_cidr_block: typing.Optional[builtins.str] = None,
+    enables_internet_connectivity: typing.Optional[builtins.bool] = None,
+    existing_vpc_peering_route_key: typing.Optional[builtins.str] = None,
+    router_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df3f88ed1cc891dbd636f210624927d010c33ac961e6f577806e2dd937c456be(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    subnets: typing.Sequence[ISubnetsProps],
+    vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+    peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__92666cd41c2c14d24ac75176f78720cccdba04127eb90a149be6f2fe21660cf1(
+    option: ISubnetsProps,
+    vpc: _aws_cdk_aws_ec2_ceddda9d.Vpc,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f78b8adef4396361d5c72de5dc0fba4922e4d9a7322c65f75ff8504d4bd76871(
+    value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b69712fe7b2bc40ff22d1946b13d47d502e7bdb75a27de5e82a782f5b1e5ad06(
+    value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b5bfb10a99897571241006d792ce84acf324e915d0d0d7a70310260bbf97506a(
+    value: typing.List[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5a1970396c779835fc4afcade9ad3fdc707402f18a94acc262cf9e711955157f(
+    *,
+    cidr: _aws_cdk_aws_ec2_ceddda9d.AclCidr,
+    traffic: _aws_cdk_aws_ec2_ceddda9d.AclTraffic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__906788234b850289efe7c3dfd41ad9a7598ad048a1820338c1962e640c00d246(
+    *,
+    peering_vpc_id: builtins.str,
+    tags: typing.Mapping[builtins.str, builtins.str],
+    peer_assume_role_arn: typing.Optional[builtins.str] = None,
+    peer_owner_id: typing.Optional[builtins.str] = None,
+    peer_region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__276e14ede93619c8496d33625e8b9426df9db19c536b76f6785db1fff0434a40(
+    *,
+    subnets: typing.Sequence[ISubnetsProps],
+    vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+    peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
